#![cfg_attr(docsrs, feature(doc_cfg))]
#![warn(clippy::print_stderr)]
#![warn(clippy::print_stdout)]

#[rustfmt::skip]
mod vars_codegen;

pub use crate::vars_codegen::*;

pub use varcon_core::Category;
pub use varcon_core::CategorySet;
